Module error

Module error 

Error types for problems that may arise when reading or storing wallet data to SQLite.

Enums

BackendError
A zcash_client_backend error carrying a variant that this crate has no translation for, as reported by SqliteClientError::BackendError.
SqliteClientError
The primary error type for the SQLite wallet backend.