Available on crate features
test-dependencies only.Expand description
Test utilities for clock simulation.
Structs
- Fixed
Clock - A
Clockimpl that always returns a constant value for calls tonow.
test-dependencies only.Test utilities for clock simulation.
Clock impl that always returns a constant value for calls to now.