#[non_exhaustive]pub enum WalletMigrationError {
DatabaseNotSupported(String),
SeedRequired,
SeedNotRelevant,
CorruptedData(String),
AddressGeneration(AddressGenerationError),
DbError(Error),
BalanceError(BalanceError),
CommitmentTree(Box<ShardTreeError<Error>>),
CannotRevert(Uuid),
Other(Box<SqliteClientError>),
}Expand description
Errors that can occur when applying migrations to the wallet database.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DatabaseNotSupported(String)
A feature required by the wallet database is not supported by the version of SQLite that the migration is running against.
SeedRequired
The seed is required for the migration.
SeedNotRelevant
A seed was provided that is not relevant to any of the accounts within the wallet.
Specifically, it is not relevant to any account for which Account::source is
AccountSource::Derived. We do not check whether the seed is relevant to any
imported account, because that would require brute-forcing the ZIP 32 account
index space.
CorruptedData(String)
Decoding of an existing value from its serialized form has failed.
AddressGeneration(AddressGenerationError)
An error occurred in migrating a Zcash address or key.
DbError(Error)
Wrapper for rusqlite errors.
BalanceError(BalanceError)
Wrapper for amount balance violations
CommitmentTree(Box<ShardTreeError<Error>>)
Wrapper for commitment tree invariant violations
CannotRevert(Uuid)
Reverting the specified migration is not supported.
Other(Box<SqliteClientError>)
Some other unexpected violation of database business rules occurred