Error types for problems that may arise when reading or storing wallet data to SQLite.
Enums
- Backend
Error - A
zcash_client_backenderror carrying a variant that this crate has no translation for, as reported bySqliteClientError::BackendError. - Sqlite
Client Error - The primary error type for the SQLite wallet backend.